@@ -551,6 +551,14 @@ def fill_run_subparser(subparsers):
         action="store_true",
         help="override any configuration enabling cache lookup for call outputs & downloaded files",
     )
+    group.add_argument(
+        "--env",
+        action="append",
+        metavar="VARNAME[=VALUE]",
+        type=str,
+        help="Environment variable to pass through to [or set outright in]"
+        " all task environments (portability warning: non-standard side channel)",
+    )
     group.add_argument(
         "--copy-input-files",
         action="store_true",
@@ -583,6 +591,7 @@ def runner(
     cfg=None,
     runtime_cpu_max=None,
     runtime_memory_max=None,
+    env=[],
     runtime_defaults=None,
     max_tasks=None,
     copy_input_files=False,
@@ -661,6 +670,8 @@ def runner(
                     cfg_overrides["task_runtime"]["defaults"] = infile.read()
         if runtime_cpu_max is not None:
             cfg_overrides["task_runtime"]["cpu_max"] = runtime_cpu_max
+        if env:
+            cfg_overrides["task_runtime"]["env"] = runner_env_override(cfg, env)
         if runtime_memory_max is not None:
             runtime_memory_max = (
                 -1 if runtime_memory_max.strip() == "-1" else parse_byte_size(runtime_memory_max)
@@ -672,6 +683,10 @@ def runner(
 
         cfg.override(cfg_overrides)
         cfg.log_all()
+        if cfg["task_runtime"].get_dict("env"):
+            logger.warning(
+                "--env is a non-standard side channel; relying on it is probably not portable"
+            )
 
         # check root
         if not path_really_within((run_dir or os.getcwd()), cfg["file_io"]["root"]):
@@ -1096,6 +1111,20 @@ def runner_input_help(target):
         print(line, file=sys.stderr)
 
 
+def runner_env_override(cfg, args):
+    env_override = cfg["task_runtime"].get_dict("env")
+    for item in args:
+        sep = item.find("=")
+        if sep == 0:
+            raise Error.InputError("invalid --env argument: " + item)
+        name = item[: sep if sep >= 0 else len(item)]
+        value = None
+        if sep != -1:
+            value = item[sep + 1 :]
+        env_override[name] = value
+    return env_override
+
+
 def is_constant_expr(expr):
     """
     Decide if the expression is "constant" for the above purposes
@@ -1320,7 +1349,7 @@ def run_self_test(**kwargs):
     if kwargs["log_json"]:
         argv.append("--log-json")
     try:
-        outputs = main(argv)["outputs"]
+        outputs = main(argv)["outputs"]  # pylint: disable=E1136
         assert len(outputs["hello_caller.messages"]) == 2
         assert outputs["hello_caller.messages"][0].rstrip() == "Hello, Alyssa P. Hacker!"
         assert outputs["hello_caller.messages"][1].rstrip() == "Hello, Ben Bitdiddle!"
